@@ -188,7 +188,6 @@ void sstp_log_msg(int level, const char *file, int line, const char *fmt, ...)
         m_ctx.token[0])
     {
         const char *ptr;
-        int index;
         
         ptr = strrchr(file, '/');
         ptr = (ptr != NULL)
@@ -329,7 +328,7 @@ status_t sstp_init_log(const char *name, int opts, int level)
     strncpy(m_ctx.appname, (name == NULL) 
             ? SSTP_DFLT_APPNAME 
             : name,
-        sizeof(m_ctx.appname));
+        sizeof(m_ctx.appname)-1);
 
     return SSTP_OKAY;
 }
@@ -397,7 +396,7 @@ status_t sstp_log_init_argv(int *argc, char *argv[])
         }
         
         /* Found no such option */
-        if (option == NULL)
+        if (!option->name)
         {
             continue;
         }
@@ -421,7 +420,7 @@ status_t sstp_log_init_argv(int *argc, char *argv[])
             }
             
             log_ctx_st *ctx = &m_ctx.syslog;
-            strncpy(ctx->file, argv[index+1], sizeof(ctx->file));
+            strncpy(ctx->file, argv[index+1], sizeof(ctx->file)-1);
             break; 
         }
         case 102:
@@ -458,7 +457,7 @@ status_t sstp_log_init_argv(int *argc, char *argv[])
                 break;
             }
             log_ctx_st *ctx = &m_ctx.file;
-            strncpy(ctx->file, argv[index+1], sizeof(ctx->file));
+            strncpy(ctx->file, argv[index+1], sizeof(ctx->file)-1);
             break;
         }   
         case 107:
@@ -588,9 +587,10 @@ status_t sstp_log_fini(void)
 }
 
 
-#ifdef __TEST_SSTP_LOG
+#ifdef __SSTP_UNIT_TEST_LOG
 
 
+#define TEST_SSTP_IDENT     "sstp-client"
 #define TEST_SSTP_HOSTNAME  "sstp-test"
 #define TEST_SSTP_MESSAGE   "This is a test message"
 #define TEST_SSTP_RESULT    "Jan  1, 00:00:00 [sstp-client]: (sstp-log.c:487) This is a test message\n"
@@ -605,6 +605,7 @@ static char message[255];
 int gethostname(char *host, size_t size)
 {
     strncpy(host, TEST_SSTP_HOSTNAME, size);
+    return 0;
 }
 
 
@@ -700,18 +701,6 @@ status_t sstp_logfile_init(log_ctx_st *ctx)
 }
 
 
-/*!
- * @brief Override the option in our unit-test
- */
-const sstp_option_st *sstp_option_get(void)
-{
-    static sstp_option_st opts;
-    opts.dlevel = 3;
-    SSTP_FL_SET(&opts, LOGFILE);
-    return &opts;
-}
-
-
 /*!
  * @brief Execute the unit-test
  */
@@ -721,7 +710,7 @@ int main(int argc, char *argv[])
     int status = 0;
 
     /* Initialize the log-library */
-    status = sstp_init_log();
+    status = sstp_init_log(TEST_SSTP_IDENT, SSTP_OPT_SYSLOG, SSTP_LOG_ERR);
     if (SSTP_OKAY != status)
     {
         printf("Failed to initialize sstp-log\n");
@@ -740,7 +729,7 @@ int main(int argc, char *argv[])
     }
 
     /* Close the log-library */
-    status = sstp_fini_log();
+    status = sstp_log_fini();
     if (SSTP_OKAY != status)
     {
         printf("Failed to de-initialize sstp-log\n");
@@ -755,5 +744,5 @@ done:
     return retval;
 }
 
-#endif /* #ifdef __TEST_SSTP_LOG */
+#endif /* #ifdef __SSTP_UNIT_TEST_LOG */
 
