@@ -332,8 +332,8 @@ static void sstp_client_proxy_done(sstp_client_st *client, int status)
             sstp_die("Could not create I/O stream", -1);
         }
 
-        /* Proxy asked us to authenticate, but we have no password */
-        if (!client->url->password || !client->url->password)
+        /* Proxy asked us to authenticate, but we have no user or password */
+        if (!client->url->user || !client->url->password)
         {
             sstp_die("Proxy asked for credentials, none provided", -1);
         }
@@ -343,7 +343,7 @@ static void sstp_client_proxy_done(sstp_client_st *client, int status)
                 client->url->password);
 
         /* Reconnect to the proxy (now with credentials set) */
-        ret = sstp_stream_connect(client->stream, (struct sockaddr*) &client->host.addr, client->host.alen,
+        sstp_stream_connect(client->stream, (struct sockaddr*) &client->host.addr, client->host.alen,
                 (sstp_complete_fn) sstp_client_proxy_connected, client, 10);
         break;
 
@@ -438,7 +438,7 @@ static status_t sstp_client_connect(sstp_client_st *client,
         {
             /* Use the host per --host option, if specified */
             strncpy(client->host.name, opts->host, 
-                    sizeof(client->host.name));
+                    sizeof(client->host.name)-1);
         }
         complete_cb = sstp_client_connected;
     }
@@ -691,7 +691,7 @@ static status_t sstp_client_lookup(sstp_url_st *uri, sstp_peer_st *peer)
     }
 
     /* Save the results for later */
-    strncpy(peer->name, (list->ai_canonname) ? : uri->host, sizeof(peer->name));
+    strncpy(peer->name, (list->ai_canonname) ? : uri->host, sizeof(peer->name)-1);
     peer->alen = list->ai_addrlen;
     memcpy(&peer->addr, list->ai_addr, peer->alen);
 
