@@ -273,8 +273,7 @@ static status_t sstp_http_send_hello(sstp_http_st *http,
     }
 
     /* Add the UUID attribute */
-    ret = sstp_buff_print(http->buf, "SSTPCORRELATIONID: %s\r\n\r\n", 
-            http->uuid, strlen(http->uuid));
+    ret = sstp_buff_print(http->buf, "SSTPCORRELATIONID: %s\r\n\r\n", http->uuid);
     if (SSTP_OKAY != ret)
     {
         return ret;
@@ -297,10 +296,6 @@ status_t sstp_http_handshake(sstp_http_st *http, sstp_stream_st *stream)
 
         /* Send the sstp hello to the server */
         ret = sstp_http_send_hello(http, stream);
-        if (SSTP_OKAY != ret)
-        {
-            break;
-        }
         break;
 
     case SSTP_MODE_SERVER:
@@ -387,7 +382,7 @@ void sstp_http_setcreds(sstp_http_st *http, const char *user,
  */
 void sstp_http_setuuid(sstp_http_st *http, const char *uuid)
 {
-    strncpy(http->uuid, uuid, sizeof(http->uuid));
+    strncpy(http->uuid, uuid, sizeof(http->uuid)-1);
 }
 
 
