@@ -29,6 +29,8 @@
 #include <unistd.h>
 #include <paths.h>
 #include <stdbool.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
 #include "sstp-private.h"
 
@@ -325,9 +327,9 @@ static void sstp_pppd_check_auth(sstp_pppd_st* ctx, sstp_buff_st *tx)
  */
 static status_t ppp_process_data(sstp_pppd_st *ctx)
 {
+    status_t ret;
     sstp_buff_st *rx = ctx->rx_buf;
     sstp_buff_st *tx = ctx->tx_buf;
-    status_t ret = SSTP_FAIL;
 
     /* Initialize TX-buffer */
     sstp_buff_reset(tx);
@@ -515,8 +517,8 @@ done:
 status_t sstp_pppd_start(sstp_pppd_st *ctx, sstp_option_st *opts,
         const char *sockname)
 {
+    status_t ret;
     status_t status  = SSTP_FAIL;
-    status_t ret     = SSTP_FAIL;
 
     /* Launch PPPd, unless PPPd launched us */
     if (!(SSTP_OPT_NOLAUNCH & opts->enable))
@@ -550,6 +552,8 @@ status_t sstp_pppd_start(sstp_pppd_st *ctx, sstp_option_st *opts,
         {
             int fd = 0;
             char buff[255];
+            /* 077, all new files created will only be read-/write- able by current user */
+            mode_t mode = umask(S_IRWXG | S_IRWXO);
 
             sprintf(ctx->tmpfile, "%s/sstp-pppd.XXXXXX", SSTP_TMP_PATH);
 
@@ -561,6 +565,9 @@ status_t sstp_pppd_start(sstp_pppd_st *ctx, sstp_option_st *opts,
                 goto done;
             }
 
+            /* Restore the umask */
+            umask(mode);
+
             /* Dump password to temporary file */
             j = snprintf(buff, sizeof(buff), "password \"%s\"\n", opts->password);
             if (write(fd, buff, j) != j)
