@@ -338,7 +338,6 @@ static status_t sstp_state_connect_nak(sstp_state_st *ctx, sstp_msg_t type,
     /* Get the status */
     memcpy(&status, &data[index], sizeof(status));
     ctx->status = ntohl(status);
-    index += sizeof(status);
     
     /* Success! */
     retval = SSTP_OKAY;
@@ -682,31 +681,31 @@ status_t sstp_state_accept(sstp_state_st *ctx)
 status_t sstp_state_mppe_keys(sstp_state_st *ctx, unsigned char *send_key, 
         unsigned char* recv_key, size_t key_len)
 {
-    status_t status = SSTP_FAIL;
-    
     /* Truncate if input is larger than supported */
-    if (key_len > sizeof(ctx->mppe_send_key)) {
+    if (key_len > sizeof(ctx->mppe_send_key))
+    {
         key_len = sizeof(ctx->mppe_send_key);
     }
 
     /* Copy the MPPE keys */
-    if (key_len > 0) {
-        memcpy(ctx->mppe_send_key, send_key, key_len);
-    }
+    if (key_len > 0) 
+    {
+        if (send_key)
+        {
+            memcpy(ctx->mppe_send_key, send_key, key_len);
+        }
 
-    if (key_len > 0) {
-        memcpy(ctx->mppe_recv_key, recv_key, key_len);
+        if (recv_key)
+        {
+            memcpy(ctx->mppe_recv_key, recv_key, key_len);
+        }
     }
 
     /* Save the incoming keylen */
     ctx->mppe_key_len = key_len;
 
     /* Success */
-    status = SSTP_OKAY;
-
-done:
-
-    return status;
+    return SSTP_OKAY;
 }
 
 
@@ -747,7 +746,7 @@ void sstp_state_free(sstp_state_st *state)
 status_t sstp_state_create(sstp_state_st **state, sstp_stream_st *stream,
         sstp_state_change_fn state_cb, void *ctx, int mode)
 {
-    int status = 0;
+    int status = SSTP_FAIL;
     int ret    = 0;
 
     /* Allocate memory for the state object */
